pub struct ValueMap(/* private fields */);Available on crate feature
xml only.Expand description
A mapping from tag names to Values.
Implementations
Sourceimpl ValueMap
impl ValueMap
pub fn new() -> ValueMap
Sourcepub fn get<'v, E>(&'v self) -> Option<Result<E, Error>>
pub fn get<'v, E>(&'v self) -> Option<Result<E, Error>>
Extract a child element of a specific type.
Returns
Noneif the element doesn’t existSome(Ok(_))if the element exists and was successfully extractedSome(Err(_))if the element exists and extraction failed
Sourcepub fn get_optional<'v, E>(&'v self) -> Option<Option<Result<E, Error>>>
pub fn get_optional<'v, E>(&'v self) -> Option<Option<Result<E, Error>>>
Extract a non-empty child element of a specific type.
Returns
Noneif the element doesn’t existSome(None)if the element exists and is emptySome(Some(Ok(_)))if the element exists, is not empty and was successfully extractedSome(Some(Err(_)))if the element exists, is not empty and extraction failed